@@ -5,7 +5,7 @@
 # This module is part of ColanderAlchemy and is released under
 # the MIT License: http://www.opensource.org/licenses/mit-license.php
 
-from .types import SQLAlchemyMapping
-from .utils import MappingRegistry
+from types import SQLAlchemyMapping
+from utils import MappingRegistry
 
 __all__ = ['SQLAlchemyMapping', 'MappingRegistry']
