@@ -16,14 +16,11 @@ __all__ = ['MappingRegistry']
 
 class MappingRegistry(object):
 
-    def __init__(self, cls, excludes=None, includes=None, nullables=None):
-        """ Keep information about the SQLAlchemy mapped class `cls`.
-        """
+    def __init__(self, cls, excludes=None, nullables=None):
         self.cls = cls
         self._mapper = class_mapper(cls)
-        self.excludes = excludes or set()
-        self.includes = includes or set()
-        self.nullables = nullables or {}
+        self.excludes = excludes if excludes else set()
+        self.nullables = nullables if nullables else {}
         self.pkeys = [col.name for col in self._mapper.primary_key]
         self.fkeys = {}
         self.rkeys = {}
@@ -33,10 +30,8 @@ class MappingRegistry(object):
         self.references = set()
         self.collections = set()
 
-        if self.includes and self.excludes:
-            raise ValueError('includes and excludes parameters are exclusive, specify only one of them')
-
         for p in self._mapper.iterate_properties:
+
             if isinstance(p, ColumnProperty):
                 self.attrs[p.key] = p.columns[0]
                 self.fields.add(p.key)
@@ -66,7 +61,7 @@ class MappingRegistry(object):
                         self.fkeys.pop(p.key)
             else:
                 msg = 'Unsupported property type: {}'.format(type(p))
-                raise NotImplementedError(msg)
+                NotImplementedError(msg)
 
         self._log = getLogger(__name__)
         self._log.debug('Registry created.')
